#
# spec file for package python-Paver
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-Paver
Version:        1.3.4
Release:        lp152.1.21
Summary:        Build, distribution and deployment scripting
License:        BSD-3-Clause
Group:          Development/Libraries/Python
URL:            https://github.com/paver/paver
Source:         https://files.pythonhosted.org/packages/source/P/Paver/Paver-%{version}.tar.gz
BuildRequires:  %{python_module cogapp}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module virtualenv}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-six
Requires(post): update-alternatives
Requires(preun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Paver is a Python-based build/distribution/deployment scripting tool along the
lines of Make or Rake. Paver integrates with commonly
used Python libraries.

%prep
%setup -q -n Paver-%{version}
rm paver/docs/.buildinfo
chmod a-x paver/docs/*.*
chmod a-x paver/docs/*/*.*

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/paver

%check
%python_exec setup.py test

%post
%python_install_alternative paver

%preun
%python_uninstall_alternative paver

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%doc paver/docs/
%python_alternative %{_bindir}/paver
%{python_sitelib}/paver/
%{python_sitelib}/Paver-%{version}-py*.egg-info

%changelog
* Fri Aug 23 2019 Jan Engelhardt <jengelh@inai.de>
- Trim bias and filler wording from description.
* Wed Aug 21 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.3.7:
  * Enormous changelog, please see docs/changelog.html
* Tue Apr 18 2017 toddrme2178@gmail.com
- Update to version 1.2.4
  * Enormous changelog, please see docs/changelog.html
- Implement single-spec version.
* Sat Aug 25 2012 cfarrell@suse.com
- Updated to 1.1.1
  * Minilib is now imported only if full paver is not available (github issue #13)
  * Option instances may now be passed to @cmdopts (github issues #41 and #42, thanks to David Cramer)
  * --propagate-traceback option for debugging ``BuildFailure``s (github issue #43)
  * Fix misleading error message when non-task is passed to @needs (github issue #37)
  * @no_help to provide a way to hide task from paver help (github issue #36)
  * @might_call for more complex dependencies (see docs, not only github issue #16)
  * bundled path.py upgraded to patched version 2.2.2 (github issue #15)
- Updated to 1.0.5
  1.0.5 (October 21, 2011)
  * Ability to share command line options between tasks (github issue `#7 <https://github.com/paver/paver/issues/issue/7>`_)
  * Flush after print (github issue `#17 <https://github.com/paver/paver/issues/issue/17>`_, thanks to Honza Kral)
  * Minilib is now compatible with zipimport (github issue `#19 <https://github.com/paver/paver/issues/issue/19>`_, thanks to Piet Delport)
  * Auto task is now properly not called when target task is decorated with no_auto
    (github issue `#4 <https://github.com/paver/paver/issues/issue/24>`_)
  1.0.4 (January 16, 2011)
  * Fixed md5 deprecation warnings in the bundled cog (thanks to jszakmeister, issue #56)
  * Project moved to github
  * Fixed problems with negative command-line options for distutils
    (thanks to Nao Nakashima for bugreport, github `issue #2 <https://github.com/paver/paver/issues/2>`_)
  * Japanese translation moved to `https://github.com/paver/paver-docs-jp  <http://paver.github.com/paver-docs-jp/>`_
  * Tasks take cmdopts even from grandparents (thanks to aurelianito, github issue #4)
  * Task description is taken from the first sentence, where the end of the sentence is dot
    followed by alphanumeric character (google code bug #44). Description is also stripped now.
  1.0.3 (June 1, 2010)
  * Fixed deadlock problem when there's a lot of output from a subprocess (thanks to Jeremy Rossi)
  * Fixed unit tests (thanks to Elias Alma)
  1.0.2 (March 8, 2010)
  * FIXED A command that outputs to stderr containing formatting directives (%%s) or something
    that looks like one would cause an error. Thanks to disturbyte for the patch.
  * Tasks can take normal keyword arguments
  * Returns exit code 1 if any tasks fail
  * stderr is no longer swallowed up by sh() (issue #37, thanks to Marc Sibson for
    the patch)
